@@ -1,33 +1,142 @@
-def launch_pages_internals(route_message_html, route_message, pageamt, htmlpageamt):
+class bcolors:
+    HEADER = '\033[95m'
+    OKBLUE = '\033[94m'
+    OKCYAN = '\033[96m'
+    OKGREEN = '\033[92m'
+    WARNING = '\033[93m'
+    FAIL = '\033[91m'
+    ENDC = '\033[0m'
+    BOLD = '\033[1m'
+    UNDERLINE = '\033[4m'
+
+
+def create_page(route='/', horm=':)'):
+    global htmlpagenum
+    global pagenum
+    try:
+        if not done:
+            initialize(True)
+        htmlpagenum = initialize(True)
+        pagenum = initialize(False)
+        if ".html" in horm:
+            if htmlpagenum <= 50:
+                route_message_html[htmlpagenum]["route"] = route
+                route_message_html[htmlpagenum]["html-path"] = horm
+                htmlpagenum += 1
+            else:
+                print(f"{bcolors.WARNING}No HTML Pages Left to use :(")
+        else:
+            if pagenum <= 50:
+                route_message[pagenum]["route"] = route
+                route_message[pagenum]["message"] = horm
+                pagenum += 1
+            else:
+                print(f"{bcolors.WARNING}No Pages Left to use :(")
+    except NameError:
+        initialize(True)
+        htmlpagenum = initialize(True)
+        pagenum = initialize(False)
+        if ".html" in horm:
+            if htmlpagenum <= 50:
+                route_message_html[htmlpagenum]["route"] = route
+                route_message_html[htmlpagenum]["html-path"] = horm
+                htmlpagenum += 1
+            else:
+                print(f"{bcolors.WARNING}No HTML Pages Left to use :(")
+        else:
+            if pagenum <= 50:
+                route_message[pagenum]["route"] = route
+                route_message[pagenum]["message"] = horm
+                pagenum += 1
+            else:
+                print(f"{bcolors.WARNING}No Pages Left to use :(")
+
+
+def launch_pages(port=6969, daemon=False):
+    from threading import Thread
+    thread_data = Thread(target=launch_pages_internals, args=(port, route_message_html, route_message, pagenum, htmlpagenum), daemon=daemon)
+    return thread_data
+
+
+def launch_pages_nothread(port=6969):
+    launch_pages_internals(port, route_message_html, route_message, pagenum, htmlpagenum)
+
+
+def initialize(html):
+    global route_message_html
+    global route_message
+    global pagenum
+    global htmlpagenum
+    global done
+    try:
+        done + 1
+    except NameError:
+        pagenum = 0
+        htmlpagenum = 0
+        route_message_html = {}
+        route_message = {}
+        for i in range(50):
+            route_message_html[i] = {}
+            route_message[i] = {}
+            route_message_html[i]['route'] = '/PingServerIsTheBestForThingsLikeLongURLSJK'
+            route_message[i]['route'] = '/PingServerIsTheBestForThingsLikeLongURLSJK'
+            route_message_html[i]['message'] = ':('
+            route_message[i]['html-path'] = 'If you use the default for html your bad'
+        done = True
+    if done is True:
+        if html is True:
+            return htmlpagenum
+        else:
+            return pagenum
+
+
+def launch_pages_internals(port, route_message_html, route_message, pageamt, htmlpageamt):
     from flask import Flask
     import random
 
+    if port == 6969:
+        port = random.randint(2000, 9000)
+
     app = Flask('app')
+    print(htmlpageamt, '&', pageamt)
+    # 1
+    if htmlpageamt <= 1:
+        html_1(app, route_message_html)
+    if pageamt <= 1:
+        string_1(app, route_message)
 
     # 10
-    if htmlpageamt <= 10:
-        html_10(app, route_message_html)
-    if pageamt <= 10:
-        string_10(app, route_message)
+    if htmlpageamt > 1:
+        if htmlpageamt <= 10:
+            html_1(app, route_message_html)
+            html_10(app, route_message_html)
+    if pageamt > 1:
+        if pageamt <= 10:
+            string_1(app, route_message)
+            string_10(app, route_message)
 
     # 20
     if htmlpageamt > 10:
         if htmlpageamt <= 20:
+            html_1(app, route_message_html)
             html_10(app, route_message_html)
             html_20(app, route_message_html)
     if pageamt > 10:
         if pageamt <= 20:
+            string_1(app, route_message)
             string_10(app, route_message)
             string_20(app, route_message)
 
     # 30
     if htmlpageamt > 20:
         if htmlpageamt <= 30:
+            html_1(app, route_message_html)
             html_10(app, route_message_html)
             html_20(app, route_message_html)
             html_30(app, route_message_html)
     if pageamt > 20:
         if pageamt <= 30:
+            string_1(app, route_message)
             string_10(app, route_message)
             string_20(app, route_message)
             string_30(app, route_message)
@@ -35,12 +144,14 @@ def launch_pages_internals(route_message_html, route_message, pageamt, htmlpagea
     # 40
     if htmlpageamt > 30:
         if htmlpageamt <= 40:
+            html_1(app, route_message_html)
             html_10(app, route_message_html)
             html_20(app, route_message_html)
             html_30(app, route_message_html)
             html_40(app, route_message_html)
     if pageamt > 30:
         if pageamt <= 40:
+            string_1(app, route_message)
             string_10(app, route_message)
             string_20(app, route_message)
             string_30(app, route_message)
@@ -49,6 +160,7 @@ def launch_pages_internals(route_message_html, route_message, pageamt, htmlpagea
     # 50
     if htmlpageamt > 40:
         if htmlpageamt <= 50:
+            html_1(app, route_message_html)
             html_10(app, route_message_html)
             html_20(app, route_message_html)
             html_30(app, route_message_html)
@@ -56,6 +168,7 @@ def launch_pages_internals(route_message_html, route_message, pageamt, htmlpagea
             html_50(app, route_message_html)
     if pageamt > 40:
         if pageamt <= 50:
+            string_1(app, route_message)
             string_10(app, route_message)
             string_20(app, route_message)
             string_30(app, route_message)
@@ -70,20 +183,23 @@ def launch_pages_internals(route_message_html, route_message, pageamt, htmlpagea
         html_40(app, route_message_html)
         html_50(app, route_message_html)
     if pageamt >= 51:
+        string_1(app, route_message)
         string_10(app, route_message)
         string_20(app, route_message)
         string_30(app, route_message)
         string_40(app, route_message)
         string_50(app, route_message)
 
-    app.run(host='0.0.0.0', port=random.randint(2000, 9000))
+    app.run(host='0.0.0.0', port=port)
 
 
-def string_10(app, route_message):
+def string_1(app, route_message):
     @app.route(route_message[0]['route'])
     def Server_0():
         return route_message[0]['message']
 
+
+def string_10(app, route_message):
     @app.route(route_message[1]['route'])
     def Server_1():
         return route_message[1]['message']
@@ -289,13 +405,17 @@ def string_50(app, route_message):
         return route_message[49]['message']
 
 
-def html_10(app, route_message_html):
+def html_1(app, route_message_html):
     from flask import render_template
 
     @app.route(route_message_html[0]['route'])
     def Server_50():
         return render_template(route_message_html[0]['html-path'])
 
+
+def html_10(app, route_message_html):
+    from flask import render_template
+
     @app.route(route_message_html[1]['route'])
     def Server_51():
         return render_template(route_message_html[1]['html-path'])
